# Generated by roxygen2: do not edit by hand

S3method("[",gdpar_formula_set)
S3method("[[",gdpar_formula_set)
S3method(as.data.frame,gdpar_coef)
S3method(as.data.frame,gdpar_preflight_report)
S3method(base::print,gdpar_param_spec)
S3method(bayesplot::pp_check,gdpar_fit)
S3method(coef,gdpar_eb_fit)
S3method(coef,gdpar_fit)
S3method(format,gdpar_coef)
S3method(format,gdpar_preflight_report)
S3method(length,gdpar_formula_set)
S3method(names,gdpar_formula_set)
S3method(predict,gdpar_causal_bridge)
S3method(predict,gdpar_eb_fit)
S3method(predict,gdpar_fit)
S3method(predict,gdpar_meta_learner_comparison)
S3method(print,W_basis)
S3method(print,amm_builder)
S3method(print,amm_spec)
S3method(print,dims_spec)
S3method(print,gdpar_bvm_report)
S3method(print,gdpar_causal_bridge)
S3method(print,gdpar_coef)
S3method(print,gdpar_contraction_report)
S3method(print,gdpar_dependence_diagnostic)
S3method(print,gdpar_dependence_robust)
S3method(print,gdpar_diagnostics)
S3method(print,gdpar_eb_fb_comparison)
S3method(print,gdpar_eb_fit)
S3method(print,gdpar_family)
S3method(print,gdpar_family_multi)
S3method(print,gdpar_fit)
S3method(print,gdpar_formula_set)
S3method(print,gdpar_geom_bridge)
S3method(print,gdpar_geom_certificate)
S3method(print,gdpar_geom_fit)
S3method(print,gdpar_geom_hmc)
S3method(print,gdpar_geom_laplace)
S3method(print,gdpar_geom_orchestration)
S3method(print,gdpar_geom_rmhmc_adaptive)
S3method(print,gdpar_geom_target)
S3method(print,gdpar_geometry_diagnostic)
S3method(print,gdpar_geometry_target)
S3method(print,gdpar_identifiability_report)
S3method(print,gdpar_ksd_joint)
S3method(print,gdpar_meta_learner_adapter)
S3method(print,gdpar_meta_learner_comparison)
S3method(print,gdpar_preflight_report)
S3method(print,gdpar_prior)
S3method(print,gdpar_spatial_dependence_diagnostic)
S3method(print,gdpar_spatial_dependence_robust)
S3method(print,summary.gdpar_causal_bridge)
S3method(print,summary.gdpar_eb_fb_comparison)
S3method(print,summary.gdpar_eb_fit)
S3method(print,summary.gdpar_ksd_joint)
S3method(print,summary.gdpar_meta_learner_comparison)
S3method(residuals,gdpar_fit)
S3method(summary,gdpar_causal_bridge)
S3method(summary,gdpar_coef)
S3method(summary,gdpar_eb_fb_comparison)
S3method(summary,gdpar_eb_fit)
S3method(summary,gdpar_fit)
S3method(summary,gdpar_ksd_joint)
S3method(summary,gdpar_meta_learner_comparison)
S3method(summary,gdpar_preflight_report)
export(W_basis)
export(amm_build)
export(amm_load_spec)
export(amm_save_spec)
export(amm_set_W)
export(amm_set_a)
export(amm_set_a_uniform)
export(amm_set_b)
export(amm_set_b_uniform)
export(amm_set_x_vars)
export(amm_spec)
export(as_amm_spec)
export(as_per_k)
export(diagnostics)
export(dimwise)
export(gdpar)
export(gdpar_adapter_econml)
export(gdpar_adapter_grf)
export(gdpar_bf)
export(gdpar_bvm_check)
export(gdpar_causal_bridge)
export(gdpar_check_identifiability)
export(gdpar_compare_eb_fb)
export(gdpar_compare_meta_learners)
export(gdpar_contraction_diagnostic)
export(gdpar_dependence_diagnostic)
export(gdpar_dependence_robust)
export(gdpar_dharma_object)
export(gdpar_eb)
export(gdpar_family)
export(gdpar_family_custom)
export(gdpar_family_custom_K)
export(gdpar_family_multi)
export(gdpar_formula_set)
export(gdpar_geom_bridge)
export(gdpar_geom_fisher_simulator)
export(gdpar_geom_fit)
export(gdpar_geom_hmc)
export(gdpar_geom_laplace)
export(gdpar_geom_metric_euclidean)
export(gdpar_geom_metric_gp_fisher)
export(gdpar_geom_metric_relativistic)
export(gdpar_geom_metric_riemannian)
export(gdpar_geom_metric_subriemannian)
export(gdpar_geom_orchestrate)
export(gdpar_geom_orchestrate_budget)
export(gdpar_geom_orchestrate_criteria)
export(gdpar_geom_reservoir)
export(gdpar_geom_rmhmc_adaptive)
export(gdpar_geom_target)
export(gdpar_geometry_diagnostic)
export(gdpar_geometry_suite)
export(gdpar_geometry_thresholds)
export(gdpar_golden_compare)
export(gdpar_ksd_joint)
export(gdpar_loo)
export(gdpar_meta_learner_adapter)
export(gdpar_posterior_predict)
export(gdpar_prior)
export(gdpar_snapshot_fit)
export(gdpar_spatial_dependence_diagnostic)
export(gdpar_spatial_dependence_robust)
export(is_gdpar_meta_learner_adapter)
export(override)
export(preflight_global_decision)
export(preflight_per_dim)
importFrom(methods,is)
importFrom(stats,coef)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
