# Block 6 — synthetic adversarial multi: verdict summary

Generated at: 2026-05-19 11:39:40

| scenario | best (elpd_loo) | runner-up | gdpar rank | caveats |
|----------|------------------|-----------|------------|---------|
| S0_calibrate_replica | mgcv (-351.1) | rstanarm | 5 | - |
| S1_sanity_disjoint | gdpar (-801.3) | mgcv | 1 | - |
| S2_W_only | mgcv (-826.4) | gdpar | 2 | - |
| S3_overlap_controlled | mgcv (-571.2) | brms | 4 | - |
| S4_near_collinear | mgcv (-1159.6) | inla | 5 | - |
| S5_bernoulli_heterog | rstanarm (-929.3) | brms | 4 | - |
| S6_C4bis_overlap_stress | mgcv (-826.6) | inla | 4 | - |
| S7_heterog_p3 | mgcv (-1375.5) | brms | 4 | - |
| S8_residual_correlation | brms_rescor (-713.1) | mgcv | 6 | - |
